# eric7.Plugins.WizardPlugins.FileDialogWizard.FileDialogWizardDialog

Module implementing the file dialog wizard dialog.

### Global Attributes

None

### Classes

FileDialogWizardDialog | Class implementing the color dialog wizard dialog.

### Functions

None

## FileDialogWizardDialog

Class implementing the color dialog wizard dialog.

It displays a dialog for entering the parameters for the EricFileDialog or QFileDialog code generator.

### Derived from

QDialog, Ui_FileDialogWizardDialog

### Class Attributes

EricTypes
PyQtTypes

### Class Methods

None

### Methods

FileDialogWizardDialog | Constructor
__prepareSchemesList | Private method to prepare the list of supported schemes.
__toggleConfirmCheckBox | Private slot to enable/disable the confirmation check box.
__toggleGroupsAndTest | Private slot to enable/disable certain groups and the test button.
__toggleInitialFilterAndResult | Private slot to enable/disable the initial filter elements and the results entries.
getCode | Public method to get the source code for Qt6.
on_bTest_clicked | Private method to test the selected options.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_pyqtComboBox_currentIndexChanged | Private slot to setup the dialog for the selected PyQt variant.

### Static Methods

None

#### FileDialogWizardDialog (Constructor)

FileDialogWizardDialog(dialogVariant, parent=None)

Constructor

dialogVariant (int)
  variant of the file dialog to be generated (-2 = EricFileDialog (pathlib.Path based), -1 = EricFileDialog (string based), 0 = unknown, 5 = PyQt5, 6 = PyQt6)
parent (QWidget)
  parent widget

#### FileDialogWizardDialog.__prepareSchemesList

__prepareSchemesList()

Private method to prepare the list of supported schemes.

Return:
  string representation of the supported schemes

Return Type:
  str

#### FileDialogWizardDialog.__toggleConfirmCheckBox

__toggleConfirmCheckBox()

Private slot to enable/disable the confirmation check box.

#### FileDialogWizardDialog.__toggleGroupsAndTest

__toggleGroupsAndTest()

Private slot to enable/disable certain groups and the test button.

#### FileDialogWizardDialog.__toggleInitialFilterAndResult

__toggleInitialFilterAndResult(checkedId)

Private slot to enable/disable the initial filter elements and the results entries.

checkedId (int)
  id of the clicked button

#### FileDialogWizardDialog.getCode

getCode(indLevel, indString)

Public method to get the source code for Qt6.

indLevel (int)
  indentation level
indString (str)
  string used for indentation (space or tab)

Return:
  generated code

Return Type:
  str

#### FileDialogWizardDialog.on_bTest_clicked

on_bTest_clicked()

Private method to test the selected options.

#### FileDialogWizardDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### FileDialogWizardDialog.on_pyqtComboBox_currentIndexChanged

on_pyqtComboBox_currentIndexChanged(index)

Private slot to setup the dialog for the selected PyQt variant.

index (int)
  index of the current item

Up